:description: A cli for faster prototyping of django projects.

Falco Application
=================


.. cappa:: falco_cli.__main__.Falco

.. toctree::
   :hidden:

   Project Home <https://falcoproject.com>
   install
   commands/index
   views
   models
   pagination
   urls
   contributing
   license
   changelog
   codeofconduct
